package com.jz.dmp.modules.service.impl;

import com.jz.dmp.modules.dao.DmpTableDao;
import com.jz.dmp.modules.model.DmpTable;
import com.jz.dmp.modules.service.DmpTableService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 项目表信息(DmpTable)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-23 15:32:56
 */
@Service("dmpTableService")
public class DmpTableServiceImpl implements DmpTableService {
    @Autowired
    private DmpTableDao dmpTableDao;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public DmpTable queryById(Integer id) {
        return this.dmpTableDao.queryById(id);
    }

    /**
     * 查询多条数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    @Override
    public List<DmpTable> queryAllByLimit(int offset, int limit) {
        return this.dmpTableDao.queryAllByLimit(offset, limit);
    }

    /**
     * 新增数据
     *
     * @param dmpTable 实例对象
     * @return 实例对象
     */
    @Override
    public DmpTable insert(DmpTable dmpTable) {
        this.dmpTableDao.insert(dmpTable);
        return dmpTable;
    }

    /**
     * 修改数据
     *
     * @param dmpTable 实例对象
     * @return 实例对象
     */
    @Override
    public DmpTable update(DmpTable dmpTable) {
        this.dmpTableDao.update(dmpTable);
        return this.queryById(dmpTable.getId());
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer id) {
        return this.dmpTableDao.deleteById(id) > 0;
    }
}